#!/bin/sh

ACTION=${1}
shift 1

get_image() {
  IMAGE_NAME="ghost"
}

do_install_detail() {
  local config=`uci get ghostblog.@ghostblog[0].config_path 2>/dev/null`
  local port=`uci get ghostblog.@ghostblog[0].port 2>/dev/null`
  local IMAGE_NAME=`uci get ghostblog.@ghostblog[0].image_name 2>/dev/null`

  #Generate the generic environment variables for the docker-compose

  GEN_PASS=$(< /dev/urandom tr -dc A-Za-z0-9 2>/dev/null | head -c14; echo)
  GEN_PASS2=$(< /dev/urandom tr -dc A-Za-z0-9 2>/dev/null | head -c14; echo)
  
  # Get our local LAN IP Address
  LAN_IP=$(uci get network.lan.ipaddr)
  # Strip trailing network mask
  LAN_IP="${LAN_IP%/*}"
   
  if [ -z "$config" ]; then
      echo "config path is empty!"
      exit 1
  fi

  [ -z "$port" ] && port=2368
  [ -z "$IMAGE_NAME" ] && IMAGE_NAME=ghost

  
  # Create Docker Compose file with custom variables
   
  # Create Docker Compose file with custom variables
touch docker-compose.yml
cat > docker-compose.yml <<EOF
version: '3.1'

services:

  ghost:
    image: ${IMAGE_NAME}:latest
    restart: always
    ports:
      - ${port}:2368
    environment:
      # see https://ghost.org/docs/config/#configuration-options
      database__client: mysql
      database__connection__host: db
      database__connection__user: root
      database__connection__password: ${GEN_PASS}
      database__connection__database: ghost
      # this url value is just an example, and is likely wrong for your environment!
      url: http://${LAN_IP}:${port}
      # image defaults to NODE_ENV=production (so development mode needs to be explicitly specified if desired)
      #NODE_ENV: development

  db:
    image: mysql:8.0
    restart: always
    environment:
      MYSQL_ROOT_PASSWORD: ${GEN_PASS}
    labels:
      plugsy.name: "Ghost"
      plugsy.category: "Home"
      plugsy.icon: "@styled-icons/boxicons-logos/Ghost"
      plugsy.link: "http://${LAN_IP}:${port}" 
EOF
  
  docker-compose up -d
 
  # Add a new list option to the "shortcutmenu" configuration file
  uci add shortcutmenu lists
  uci set shortcutmenu.@lists[-1].webname="$IMAGE_NAME"
  uci set shortcutmenu.@lists[-1].weburl="$LAN_IP:$port"
  uci set shortcutmenu.@lists[-1].webpath="/"
  uci commit shortcutmenu

}

usage() {
  echo "usage: $0 sub-command"
  echo "where sub-command is one of:"
  echo "      install                Install the Ghost blog"
  echo "      upgrade                Upgrade the Ghost blog"
  echo "      rm/start/stop/restart  Remove/Start/Stop/Restart the Ghost blog"
  echo "      status                 Ghost blog status"
  echo "      port                   Ghost blog port"
}

case ${ACTION} in
  "install")
    get_image
    do_install_detail
  ;;
  "upgrade")
    get_image
    do_install_detail
  ;;
  "rm")
    docker rm -f ghost
  ;;
  "start" | "stop" | "restart")
    docker ${ACTION} ghost
  ;;
  "status")
    docker ps --all -f 'name=ghost' --format '{{.State}}'
  ;;
  "port")
    docker ps --all -f 'name=ghost' --format '{{.Ports}}' | grep -om1 '0.0.0.0:[0-9]*' | sed 's/0.0.0.0://'
  ;;
  *)
    usage
    exit 1
  ;;
esac
